struct StdinRaw(Stdin);Expand description
A handle to a raw instance of the standard input stream of this process.
This handle is not synchronized or buffered in any fashion. Constructed via
the std::io::stdio::stdin_raw function.
Tuple Fields
0: StdinTrait Implementations
Sourceimpl Read for StdinRaw
impl Read for StdinRaw
Sourcefn read(&mut self, buf: &mut [u8]) -> Result<usize>
fn read(&mut self, buf: &mut [u8]) -> Result<usize>
Pull some bytes from this source into the specified buffer, returning
how many bytes were read. Read more
Sourcefn read_buf(&mut self, buf: BorrowedCursor<'_, u8>) -> Result<()>
fn read_buf(&mut self, buf: BorrowedCursor<'_, u8>) -> Result<()>
🔬This is a nightly-only experimental API. (
read_buf #78485)Pull some bytes from this source into the specified buffer. Read more
Sourcefn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize>
fn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize>
Like
read, except that it reads into a slice of buffers. Read moreSourcefn is_read_vectored(&self) -> bool
fn is_read_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector #69941)Sourcefn read_exact(&mut self, buf: &mut [u8]) -> Result<()>
fn read_exact(&mut self, buf: &mut [u8]) -> Result<()>
Reads the exact number of bytes required to fill
buf. Read moreSourcefn read_buf_exact(&mut self, buf: BorrowedCursor<'_, u8>) -> Result<()>
fn read_buf_exact(&mut self, buf: BorrowedCursor<'_, u8>) -> Result<()>
🔬This is a nightly-only experimental API. (
read_buf #78485)Reads the exact number of bytes required to fill
cursor. Read moreSourcefn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize>
fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize>
Reads all bytes until EOF in this source, placing them into
buf. Read moreSourcefn read_to_string(&mut self, buf: &mut String) -> Result<usize>
fn read_to_string(&mut self, buf: &mut String) -> Result<usize>
Reads all bytes until EOF in this source, appending them to
buf. Read more1.0.0 · Sourcefn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
fn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
Creates a “by reference” adapter for this instance of
Read. Read more1.0.0 · Sourcefn chain<R: Read>(self, next: R) -> Chain<Self, R> ⓘwhere
Self: Sized,
fn chain<R: Read>(self, next: R) -> Chain<Self, R> ⓘwhere
Self: Sized,
Creates an adapter which will chain this stream with another. Read more
1.0.0 · Sourcefn take(self, limit: u64) -> Take<Self> ⓘwhere
Self: Sized,
fn take(self, limit: u64) -> Take<Self> ⓘwhere
Self: Sized,
Creates an adapter which will read at most
limit bytes from it. Read moreSourcefn read_array<const N: usize>(&mut self) -> Result<[u8; N]>where
Self: Sized,
fn read_array<const N: usize>(&mut self) -> Result<[u8; N]>where
Self: Sized,
🔬This is a nightly-only experimental API. (
read_array #148848)Read and return a fixed array of bytes from this source. Read more